Package: cloudosR
Type: Package
Title: 'Lifebit' Platform 'API' Client
Version: 0.2.0
Authors@R: person("Leila Mansouri", email = "leila.mansouri@lifebit.ai", role = c("aut", "cre"))
Description: Interacts with the 'Lifebit' Platform Cohort Browser 'API'
    <https://cloudos.lifebit.ai>. Enables schema discovery, table exploration,
    and read-only 'SQL' query execution with policy-aware behavior and team-based
    access control for cohort data analysis. Requires bastion-enabled workspaces
    for 'API' access.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: httr2, jsonlite, utils
Suggests: testthat (>= 3.0.0), knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-28 13:42:42 UTC; leilamansouri
Author: Leila Mansouri [aut, cre]
Maintainer: Leila Mansouri <leila.mansouri@lifebit.ai>
Repository: CRAN
Date/Publication: 2026-06-01 09:10:14 UTC
Built: R 4.6.0; ; 2026-06-01 10:23:36 UTC; unix
