% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{parse_json_response}
\alias{parse_json_response}
\title{Parse JSON Response}
\usage{
parse_json_response(response)
}
\arguments{
\item{response}{HTTP response object from httr2.}
}
\value{
Parsed JSON object.
}
\description{
Internal function to safely parse JSON response from API.
}
\keyword{internal}
