% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{null-coalesce}
\alias{null-coalesce}
\alias{\%||\%}
\title{Null-coalescing Operator}
\usage{
x \%||\% y
}
\arguments{
\item{x}{First value to check.}

\item{y}{Default value if x is NULL.}
}
\value{
x if not NULL, otherwise y.
}
\description{
Returns the left-hand side if it's not NULL, otherwise returns the right-hand side.
}
\keyword{internal}
