% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query.R
\name{print.cloudos_tables}
\alias{print.cloudos_tables}
\title{Print method for cloudos_tables}
\usage{
\method{print}{cloudos_tables}(x, ...)
}
\arguments{
\item{x}{A cloudos_tables object}

\item{...}{Additional arguments (unused)}
}
\value{
The \code{cloudos_tables} object \code{x}, returned invisibly.
  Called primarily for its side effect of printing a formatted list of
  schemas and tables to the console.
}
\description{
Print method for cloudos_tables
}
