% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/http.R
\name{http_request_with_retry}
\alias{http_request_with_retry}
\title{Make HTTP Request with Retry}
\usage{
http_request_with_retry(
  method,
  profile,
  endpoint,
  body = list(),
  query_params = list(),
  max_retries = 3,
  retry_delay = 2
)
}
\arguments{
\item{method}{Character. HTTP method ("GET" or "POST").}

\item{profile}{List. Profile configuration from load_profile().}

\item{endpoint}{Character. API endpoint path (without base URL).}

\item{body}{List. Request body (for POST requests).}

\item{query_params}{List. Query parameters.}

\item{max_retries}{Integer. Maximum number of retries (default: 3).}

\item{retry_delay}{Integer. Delay between retries in seconds (default: 2).}
}
\value{
Parsed JSON response.
}
\description{
Internal function to make HTTP requests with retry logic for transient failures.
}
\keyword{internal}
