% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/http.R
\name{build_query_string}
\alias{build_query_string}
\title{Build Query String}
\usage{
build_query_string(params)
}
\arguments{
\item{params}{List. Named list of query parameters.}
}
\value{
Character. URL-encoded query string.
}
\description{
Internal function to build URL query string from list of parameters.
}
\keyword{internal}
