% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/config.R
\name{get_config_dir}
\alias{get_config_dir}
\title{Get Config Directory Path}
\usage{
get_config_dir()
}
\value{
Character. Path to config directory.
}
\description{
Internal function to get the Lifebit Platform config directory path.
Uses tools::R_user_dir() for CRAN-compliant persistent storage.
Can be overridden with CLOUDOS_CONFIG_DIR environment variable.
}
\keyword{internal}
