% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query.R
\name{convert_results_to_dataframe}
\alias{convert_results_to_dataframe}
\title{Convert Query Results to Dataframe}
\usage{
convert_results_to_dataframe(data, column_names)
}
\arguments{
\item{data}{List. Data rows from API response.}

\item{column_names}{Character vector. Column names.}
}
\value{
Data frame with query results.
}
\description{
Internal function to convert API response data to a dataframe.
}
\keyword{internal}
