% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/config.R
\name{get_config_file}
\alias{get_config_file}
\title{Get Config File Path}
\usage{
get_config_file()
}
\value{
Character. Path to config file.
}
\description{
Internal function to get the Lifebit Platform config file path.
Config file is stored in the user's R config directory as .cloudos_config.json
using tools::R_user_dir() for CRAN compliance.
}
\keyword{internal}
